#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Applicable to webstarts"""
import shlex
import subprocess

import click
from pkg_resources import get_distribution
from semantic_version import Version

__author__ = "john"


@click.group()
def cli():
  """CLI utilities"""


@cli.command('rel')
@click.option('-n', '--num')
def release(num):
  """Release prod

  Notes:
    setup.py develop
    setup.py develop --uninstall
  """
  cmd('pip uninstall webstarts')
  cmd('python setup.py develop')
  version = num or _bump()
  cmd(f'git hf release start {version}')
  cmd(f'git hf release finish -M {version}')
  cmd('git checkout master')
  cmd('./deploy.sh')
  cmd('git checkout develop')


@cli.command()
def version():
  return print(f'Version: {_version()}')


@cli.command()
def bump():
  return print(f'Next Version: {_bump()}')


def _version():
  return get_distribution('webstarts').version


def _bump():
  v = Version.coerce(_version())
  if v.minor >= 9:
    return v.next_major()
  return v.next_minor()


def cmd(line, **kwargs):
  print(line)
  return subprocess.run(shlex.split(line), check=True, stdout=subprocess.PIPE, encoding='utf-8', **kwargs)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Applicable to shittest"""

from flask import Flask
from structlog import get_logger

from webstarts.wflask import setup_app

__author__ = "john"

logger = get_logger(__name__)


def create_app():
  app = Flask(__name__)

  setup_app(app, dsn='https://de3e703c200f443cbe375ad22b94fb3e:5f36eac41b324a86afa701cc20d3771c@sentry.io/146706', environment='local')

  from .views import bp
  app.register_blueprint(bp)

  return app



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""Applicable to shittest"""
import logging

import requests
from flask import Blueprint, jsonify, render_template, request
from structlog import get_logger

__author__ = "john"

logger: logging.Logger = get_logger(__name__)

bp = Blueprint('app', __name__)


@bp.route('/')
@bp.route('/<path:path>')
def login(path=None):
  """

  https://healthgrades.com/physician/dr-john-baldauf-35lnw
  """

  logger.debug('Why no debug')
  logging.getLogger(__name__).warning('Suck it')

  return render_template('web.html')


@bp.route('/save', methods=['POST'])
def save():
  data = {k: v for k, v in request.form.items()}
  logger.info('Saved POST', **data)
  r = requests.get('https://www.healthgrades.com/physician/dr-john-baldauf-35lnw')
  return jsonify({'suck': 'it'}), 200


@bp.route('/save2', methods=['POST'])
def save2():
  d = {}
  try:
    ff = d['a']
  except KeyError as e:
    logger.exception(e, fuck='you')
    logging.getLogger(__name__).exception(e)
    ff = None

  return jsonify({'suck': ff}), 200
